Class: Abliteration::AuthorsApi
- Inherits:
-
Object
- Object
- Abliteration::AuthorsApi
- Defined in:
- lib/abliteration/api/authors_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_author(id, opts = {}) ⇒ GetAuthor200Response
Get one author Cost: 1 credit.
-
#get_author_with_http_info(id, opts = {}) ⇒ Array<(GetAuthor200Response, Integer, Hash)>
Get one author Cost: 1 credit.
-
#initialize(api_client = ApiClient.default) ⇒ AuthorsApi
constructor
A new instance of AuthorsApi.
-
#list_authors(opts = {}) ⇒ ListAuthors200Response
List authors Cost: 5-15 credits, by rows returned.
-
#list_authors_with_http_info(opts = {}) ⇒ Array<(ListAuthors200Response, Integer, Hash)>
List authors Cost: 5-15 credits, by rows returned.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ AuthorsApi
Returns a new instance of AuthorsApi.
19 20 21 |
# File 'lib/abliteration/api/authors_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/abliteration/api/authors_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_author(id, opts = {}) ⇒ GetAuthor200Response
Get one author Cost: 1 credit.
27 28 29 30 |
# File 'lib/abliteration/api/authors_api.rb', line 27 def (id, opts = {}) data, _status_code, _headers = (id, opts) data end |
#get_author_with_http_info(id, opts = {}) ⇒ Array<(GetAuthor200Response, Integer, Hash)>
Get one author Cost: 1 credit.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/abliteration/api/authors_api.rb', line 37 def (id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthorsApi.get_author ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AuthorsApi.get_author" end # resource path local_var_path = '/api/v1/authors/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetAuthor200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AuthorsApi.get_author", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthorsApi#get_author\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_authors(opts = {}) ⇒ ListAuthors200Response
List authors Cost: 5-15 credits, by rows returned.
92 93 94 95 |
# File 'lib/abliteration/api/authors_api.rb', line 92 def (opts = {}) data, _status_code, _headers = (opts) data end |
#list_authors_with_http_info(opts = {}) ⇒ Array<(ListAuthors200Response, Integer, Hash)>
List authors Cost: 5-15 credits, by rows returned.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/abliteration/api/authors_api.rb', line 104 def (opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuthorsApi.list_authors ...' end allowable_values = ["total_downloads", "-total_downloads", "downloads", "-downloads", "total_models", "-total_models", "models", "-models", "total_likes", "-total_likes", "likes", "-likes"] if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort']) fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 1000 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling AuthorsApi.list_authors, must be smaller than or equal to 1000.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling AuthorsApi.list_authors, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0 fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling AuthorsApi.list_authors, must be greater than or equal to 0.' end # resource path local_var_path = '/api/v1/authors' # query parameters query_params = opts[:query_params] || {} query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListAuthors200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AuthorsApi.list_authors", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuthorsApi#list_authors\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |