Class: Abliteration::DatasetsApi
- Inherits:
-
Object
- Object
- Abliteration::DatasetsApi
- Defined in:
- lib/abliteration/api/datasets_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_dataset(id, opts = {}) ⇒ GetDataset200Response
Get one dataset Cost: 1 credit.
-
#get_dataset_with_http_info(id, opts = {}) ⇒ Array<(GetDataset200Response, Integer, Hash)>
Get one dataset Cost: 1 credit.
-
#initialize(api_client = ApiClient.default) ⇒ DatasetsApi
constructor
A new instance of DatasetsApi.
-
#list_datasets(opts = {}) ⇒ ListDatasets200Response
List datasets Cost: 5-15 credits, by rows returned.
-
#list_datasets_with_http_info(opts = {}) ⇒ Array<(ListDatasets200Response, Integer, Hash)>
List datasets Cost: 5-15 credits, by rows returned.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ DatasetsApi
Returns a new instance of DatasetsApi.
19 20 21 |
# File 'lib/abliteration/api/datasets_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/abliteration/api/datasets_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_dataset(id, opts = {}) ⇒ GetDataset200Response
Get one dataset Cost: 1 credit. The passport is null for datasets that do not have one yet.
27 28 29 30 |
# File 'lib/abliteration/api/datasets_api.rb', line 27 def get_dataset(id, opts = {}) data, _status_code, _headers = get_dataset_with_http_info(id, opts) data end |
#get_dataset_with_http_info(id, opts = {}) ⇒ Array<(GetDataset200Response, Integer, Hash)>
Get one dataset Cost: 1 credit. The passport is null for datasets that do not have one yet.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/abliteration/api/datasets_api.rb', line 37 def get_dataset_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DatasetsApi.get_dataset ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling DatasetsApi.get_dataset" end # resource path local_var_path = '/api/v1/datasets/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetDataset200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"DatasetsApi.get_dataset", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DatasetsApi#get_dataset\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_datasets(opts = {}) ⇒ ListDatasets200Response
List datasets Cost: 5-15 credits, by rows returned.
95 96 97 98 |
# File 'lib/abliteration/api/datasets_api.rb', line 95 def list_datasets(opts = {}) data, _status_code, _headers = list_datasets_with_http_info(opts) data end |
#list_datasets_with_http_info(opts = {}) ⇒ Array<(ListDatasets200Response, Integer, Hash)>
List datasets Cost: 5-15 credits, by rows returned.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/abliteration/api/datasets_api.rb', line 110 def list_datasets_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DatasetsApi.list_datasets ...' end allowable_values = ["downloads", "-downloads", "likes", "-likes", "created", "-created", "created_at", "-created_at", "first_seen", "-first_seen", "first_seen_at", "-first_seen_at"] if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort']) fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 1000 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling DatasetsApi.list_datasets, must be smaller than or equal to 1000.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling DatasetsApi.list_datasets, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0 fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling DatasetsApi.list_datasets, must be greater than or equal to 0.' end # resource path local_var_path = '/api/v1/datasets' # query parameters query_params = opts[:query_params] || {} query_params[:'category'] = opts[:'category'] if !opts[:'category'].nil? query_params[:'author'] = opts[:'author'] if !opts[:'author'].nil? query_params[:'license'] = opts[:'license'] if !opts[:'license'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListDatasets200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"DatasetsApi.list_datasets", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DatasetsApi#list_datasets\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |