Class: Abliteration::DeletionSummary
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Abliteration::DeletionSummary
- Defined in:
- lib/abliteration/models/deletion_summary.rb
Overview
Aggregate rollup of the 24-month HF deletion analysis.
Instance Attribute Summary collapse
-
#avg_months_alive ⇒ Object
Average lifespan of deleted models, in months.
-
#deletion_rate_pct ⇒ Object
Percentage of ever-seen models that are now gone.
-
#timeline ⇒ Object
Deletions grouped by last_seen_month, ascending.
-
#top_by_downloads ⇒ Object
Top-10 biggest casualties by peak downloads.
-
#total_deleted ⇒ Object
Returns the value of attribute total_deleted.
-
#total_ever_seen ⇒ Object
Live catalog size plus historical deletions.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DeletionSummary
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DeletionSummary
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/abliteration/models/deletion_summary.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Abliteration::DeletionSummary` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Abliteration::DeletionSummary`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'total_ever_seen') self.total_ever_seen = attributes[:'total_ever_seen'] end if attributes.key?(:'total_deleted') self.total_deleted = attributes[:'total_deleted'] end if attributes.key?(:'deletion_rate_pct') self.deletion_rate_pct = attributes[:'deletion_rate_pct'] end if attributes.key?(:'avg_months_alive') self.avg_months_alive = attributes[:'avg_months_alive'] end if attributes.key?(:'timeline') if (value = attributes[:'timeline']).is_a?(Array) self.timeline = value end end if attributes.key?(:'top_by_downloads') if (value = attributes[:'top_by_downloads']).is_a?(Array) self.top_by_downloads = value end end end |
Instance Attribute Details
#avg_months_alive ⇒ Object
Average lifespan of deleted models, in months.
28 29 30 |
# File 'lib/abliteration/models/deletion_summary.rb', line 28 def avg_months_alive @avg_months_alive end |
#deletion_rate_pct ⇒ Object
Percentage of ever-seen models that are now gone.
25 26 27 |
# File 'lib/abliteration/models/deletion_summary.rb', line 25 def deletion_rate_pct @deletion_rate_pct end |
#timeline ⇒ Object
Deletions grouped by last_seen_month, ascending.
31 32 33 |
# File 'lib/abliteration/models/deletion_summary.rb', line 31 def timeline @timeline end |
#top_by_downloads ⇒ Object
Top-10 biggest casualties by peak downloads.
34 35 36 |
# File 'lib/abliteration/models/deletion_summary.rb', line 34 def top_by_downloads @top_by_downloads end |
#total_deleted ⇒ Object
Returns the value of attribute total_deleted.
22 23 24 |
# File 'lib/abliteration/models/deletion_summary.rb', line 22 def total_deleted @total_deleted end |
#total_ever_seen ⇒ Object
Live catalog size plus historical deletions.
20 21 22 |
# File 'lib/abliteration/models/deletion_summary.rb', line 20 def total_ever_seen @total_ever_seen end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/abliteration/models/deletion_summary.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/abliteration/models/deletion_summary.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/abliteration/models/deletion_summary.rb', line 37 def self.attribute_map { :'total_ever_seen' => :'total_ever_seen', :'total_deleted' => :'total_deleted', :'deletion_rate_pct' => :'deletion_rate_pct', :'avg_months_alive' => :'avg_months_alive', :'timeline' => :'timeline', :'top_by_downloads' => :'top_by_downloads' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/abliteration/models/deletion_summary.rb', line 164 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/abliteration/models/deletion_summary.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/abliteration/models/deletion_summary.rb', line 59 def self.openapi_types { :'total_ever_seen' => :'Integer', :'total_deleted' => :'Integer', :'deletion_rate_pct' => :'Float', :'avg_months_alive' => :'Float', :'timeline' => :'Array<DeletionSummaryTimelineInner>', :'top_by_downloads' => :'Array<DeletionSummaryTopByDownloadsInner>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
138 139 140 141 142 143 144 145 146 147 |
# File 'lib/abliteration/models/deletion_summary.rb', line 138 def ==(o) return true if self.equal?(o) self.class == o.class && total_ever_seen == o.total_ever_seen && total_deleted == o.total_deleted && deletion_rate_pct == o.deletion_rate_pct && avg_months_alive == o.avg_months_alive && timeline == o.timeline && top_by_downloads == o.top_by_downloads end |
#eql?(o) ⇒ Boolean
151 152 153 |
# File 'lib/abliteration/models/deletion_summary.rb', line 151 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
157 158 159 |
# File 'lib/abliteration/models/deletion_summary.rb', line 157 def hash [total_ever_seen, total_deleted, deletion_rate_pct, avg_months_alive, timeline, top_by_downloads].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
123 124 125 126 127 |
# File 'lib/abliteration/models/deletion_summary.rb', line 123 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/abliteration/models/deletion_summary.rb', line 186 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
131 132 133 134 |
# File 'lib/abliteration/models/deletion_summary.rb', line 131 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |