Class: Abliteration::DelistedModel

Inherits:
ApiModelBase show all
Defined in:
lib/abliteration/models/delisted_model.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DelistedModel

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/abliteration/models/delisted_model.rb', line 81

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Abliteration::DelistedModel` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Abliteration::DelistedModel`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'author')
    self.author = attributes[:'author']
  end

  if attributes.key?(:'family')
    self.family = attributes[:'family']
  end

  if attributes.key?(:'params_b')
    self.params_b = attributes[:'params_b']
  end

  if attributes.key?(:'downloads')
    self.downloads = attributes[:'downloads']
  end

  if attributes.key?(:'last_seen_at')
    self.last_seen_at = attributes[:'last_seen_at']
  end

  if attributes.key?(:'days_since_gone')
    self.days_since_gone = attributes[:'days_since_gone']
  end
end

Instance Attribute Details

#author ⇒ Object

Returns the value of attribute author.



20
21
22
# File 'lib/abliteration/models/delisted_model.rb', line 20

def author
  @author
end

#days_since_gone ⇒ Object

Whole days between last_seen_at and now, computed server-side for convenience.



33
34
35
# File 'lib/abliteration/models/delisted_model.rb', line 33

def days_since_gone
  @days_since_gone
end

#downloads ⇒ Object

Downloads at the moment the model was last visible on HF. Not a live counter.



27
28
29
# File 'lib/abliteration/models/delisted_model.rb', line 27

def downloads
  @downloads
end

#family ⇒ Object

Returns the value of attribute family.



22
23
24
# File 'lib/abliteration/models/delisted_model.rb', line 22

def family
  @family
end

#id ⇒ Object

Returns the value of attribute id.



18
19
20
# File 'lib/abliteration/models/delisted_model.rb', line 18

def id
  @id
end

#last_seen_at ⇒ Object

ISO-8601 timestamp of the last successful Hub observation. Approximately when the model died.



30
31
32
# File 'lib/abliteration/models/delisted_model.rb', line 30

def last_seen_at
  @last_seen_at
end

#params_b ⇒ Object

Returns the value of attribute params_b.



24
25
26
# File 'lib/abliteration/models/delisted_model.rb', line 24

def params_b
  @params_b
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



49
50
51
# File 'lib/abliteration/models/delisted_model.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/abliteration/models/delisted_model.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
# File 'lib/abliteration/models/delisted_model.rb', line 36

def self.attribute_map
  {
    :'id' => :'id',
    :'author' => :'author',
    :'family' => :'family',
    :'params_b' => :'params_b',
    :'downloads' => :'downloads',
    :'last_seen_at' => :'last_seen_at',
    :'days_since_gone' => :'days_since_gone'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/abliteration/models/delisted_model.rb', line 168

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



72
73
74
75
76
77
# File 'lib/abliteration/models/delisted_model.rb', line 72

def self.openapi_nullable
  Set.new([
    :'family',
    :'params_b',
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
# File 'lib/abliteration/models/delisted_model.rb', line 59

def self.openapi_types
  {
    :'id' => :'String',
    :'author' => :'String',
    :'family' => :'String',
    :'params_b' => :'Float',
    :'downloads' => :'Integer',
    :'last_seen_at' => :'String',
    :'days_since_gone' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



141
142
143
144
145
146
147
148
149
150
151
# File 'lib/abliteration/models/delisted_model.rb', line 141

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      author == o.author &&
      family == o.family &&
      params_b == o.params_b &&
      downloads == o.downloads &&
      last_seen_at == o.last_seen_at &&
      days_since_gone == o.days_since_gone
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


155
156
157
# File 'lib/abliteration/models/delisted_model.rb', line 155

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



161
162
163
# File 'lib/abliteration/models/delisted_model.rb', line 161

def hash
  [id, author, family, params_b, downloads, last_seen_at, days_since_gone].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



126
127
128
129
130
# File 'lib/abliteration/models/delisted_model.rb', line 126

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/abliteration/models/delisted_model.rb', line 190

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



134
135
136
137
# File 'lib/abliteration/models/delisted_model.rb', line 134

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end