Class: Abliteration::Envelope

Inherits:
ApiModelBase show all
Defined in:
lib/abliteration/models/envelope.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Envelope

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/abliteration/models/envelope.rb', line 111

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Abliteration::Envelope` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Abliteration::Envelope`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'data')
    self.data = attributes[:'data']
  else
    self.data = nil
  end

  if attributes.key?(:'cost')
    self.cost = attributes[:'cost']
  else
    self.cost = nil
  end

  if attributes.key?(:'credits_remaining')
    self.credits_remaining = attributes[:'credits_remaining']
  else
    self.credits_remaining = nil
  end

  if attributes.key?(:'rate_limit_limit')
    self.rate_limit_limit = attributes[:'rate_limit_limit']
  else
    self.rate_limit_limit = nil
  end

  if attributes.key?(:'rate_limit_remaining')
    self.rate_limit_remaining = attributes[:'rate_limit_remaining']
  else
    self.rate_limit_remaining = nil
  end

  if attributes.key?(:'rate_limit_reset')
    self.rate_limit_reset = attributes[:'rate_limit_reset']
  else
    self.rate_limit_reset = nil
  end

  if attributes.key?(:'metering')
    self.metering = attributes[:'metering']
  else
    self.metering = nil
  end

  if attributes.key?(:'request_id')
    self.request_id = attributes[:'request_id']
  else
    self.request_id = nil
  end
end

Instance Attribute Details

#cost ⇒ Object

Credits this call costs.



22
23
24
# File 'lib/abliteration/models/envelope.rb', line 22

def cost
  @cost
end

#credits_remaining ⇒ Object

Wallet balance after the call. Unchanged while metering is preview.



25
26
27
# File 'lib/abliteration/models/envelope.rb', line 25

def credits_remaining
  @credits_remaining
end

#data ⇒ Object

The payload. An array on list routes, an object on single-entity routes.



19
20
21
# File 'lib/abliteration/models/envelope.rb', line 19

def data
  @data
end

#metering ⇒ Object

Whether cost was actually deducted.



37
38
39
# File 'lib/abliteration/models/envelope.rb', line 37

def metering
  @metering
end

#rate_limit_limit ⇒ Object

Ceiling for the current window. Also returned as X-RateLimit-Limit.



28
29
30
# File 'lib/abliteration/models/envelope.rb', line 28

def rate_limit_limit
  @rate_limit_limit
end

#rate_limit_remaining ⇒ Object

Calls left in the current window for this key. Also returned as X-RateLimit-Remaining.



31
32
33
# File 'lib/abliteration/models/envelope.rb', line 31

def rate_limit_remaining
  @rate_limit_remaining
end

#rate_limit_reset ⇒ Object

Unix seconds at which the window resets to full ceiling. Also returned as X-RateLimit-Reset.



34
35
36
# File 'lib/abliteration/models/envelope.rb', line 34

def rate_limit_reset
  @rate_limit_reset
end

#request_id ⇒ Object

Also returned in the x-request-id header.



40
41
42
# File 'lib/abliteration/models/envelope.rb', line 40

def request_id
  @request_id
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



79
80
81
# File 'lib/abliteration/models/envelope.rb', line 79

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/abliteration/models/envelope.rb', line 84

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/abliteration/models/envelope.rb', line 65

def self.attribute_map
  {
    :'data' => :'data',
    :'cost' => :'cost',
    :'credits_remaining' => :'credits_remaining',
    :'rate_limit_limit' => :'rate_limit_limit',
    :'rate_limit_remaining' => :'rate_limit_remaining',
    :'rate_limit_reset' => :'rate_limit_reset',
    :'metering' => :'metering',
    :'request_id' => :'request_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/abliteration/models/envelope.rb', line 326

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



103
104
105
106
107
# File 'lib/abliteration/models/envelope.rb', line 103

def self.openapi_nullable
  Set.new([
    :'data',
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/abliteration/models/envelope.rb', line 89

def self.openapi_types
  {
    :'data' => :'Object',
    :'cost' => :'Integer',
    :'credits_remaining' => :'Integer',
    :'rate_limit_limit' => :'Integer',
    :'rate_limit_remaining' => :'Integer',
    :'rate_limit_reset' => :'Integer',
    :'metering' => :'String',
    :'request_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/abliteration/models/envelope.rb', line 298

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      data == o.data &&
      cost == o.cost &&
      credits_remaining == o.credits_remaining &&
      rate_limit_limit == o.rate_limit_limit &&
      rate_limit_remaining == o.rate_limit_remaining &&
      rate_limit_reset == o.rate_limit_reset &&
      metering == o.metering &&
      request_id == o.request_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


313
314
315
# File 'lib/abliteration/models/envelope.rb', line 313

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



319
320
321
# File 'lib/abliteration/models/envelope.rb', line 319

def hash
  [data, cost, credits_remaining, rate_limit_limit, rate_limit_remaining, rate_limit_reset, metering, request_id].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/abliteration/models/envelope.rb', line 176

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @cost.nil?
    invalid_properties.push('invalid value for "cost", cost cannot be nil.')
  end

  if @credits_remaining.nil?
    invalid_properties.push('invalid value for "credits_remaining", credits_remaining cannot be nil.')
  end

  if @rate_limit_limit.nil?
    invalid_properties.push('invalid value for "rate_limit_limit", rate_limit_limit cannot be nil.')
  end

  if @rate_limit_remaining.nil?
    invalid_properties.push('invalid value for "rate_limit_remaining", rate_limit_remaining cannot be nil.')
  end

  if @rate_limit_reset.nil?
    invalid_properties.push('invalid value for "rate_limit_reset", rate_limit_reset cannot be nil.')
  end

  if @metering.nil?
    invalid_properties.push('invalid value for "metering", metering cannot be nil.')
  end

  if @request_id.nil?
    invalid_properties.push('invalid value for "request_id", request_id cannot be nil.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/abliteration/models/envelope.rb', line 348

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/abliteration/models/envelope.rb', line 212

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @cost.nil?
  return false if @credits_remaining.nil?
  return false if @rate_limit_limit.nil?
  return false if @rate_limit_remaining.nil?
  return false if @rate_limit_reset.nil?
  return false if @metering.nil?
  metering_validator = EnumAttributeValidator.new('String', ["preview", "billed"])
  return false unless metering_validator.valid?(@metering)
  return false if @request_id.nil?
  true
end