Class: Abliteration::Event

Inherits:
ApiModelBase show all
Defined in:
lib/abliteration/models/event.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Event

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/abliteration/models/event.rb', line 82

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Abliteration::Event` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Abliteration::Event`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  end

  if attributes.key?(:'date_precision')
    self.date_precision = attributes[:'date_precision']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'primary_source_url')
    self.primary_source_url = attributes[:'primary_source_url']
  end
end

Instance Attribute Details

#date ⇒ Object

Returns the value of attribute date.



20
21
22
# File 'lib/abliteration/models/event.rb', line 20

def date
  @date
end

#date_precision ⇒ Object

Returns the value of attribute date_precision.



22
23
24
# File 'lib/abliteration/models/event.rb', line 22

def date_precision
  @date_precision
end

#description ⇒ Object

Returns the value of attribute description.



28
29
30
# File 'lib/abliteration/models/event.rb', line 28

def description
  @description
end

#id ⇒ Object

Returns the value of attribute id.



18
19
20
# File 'lib/abliteration/models/event.rb', line 18

def id
  @id
end

#primary_source_url ⇒ Object

Returns the value of attribute primary_source_url.



30
31
32
# File 'lib/abliteration/models/event.rb', line 30

def primary_source_url
  @primary_source_url
end

#title ⇒ Object

Returns the value of attribute title.



26
27
28
# File 'lib/abliteration/models/event.rb', line 26

def title
  @title
end

#type ⇒ Object

Returns the value of attribute type.



24
25
26
# File 'lib/abliteration/models/event.rb', line 24

def type
  @type
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



46
47
48
# File 'lib/abliteration/models/event.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/abliteration/models/event.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
43
# File 'lib/abliteration/models/event.rb', line 33

def self.attribute_map
  {
    :'id' => :'id',
    :'date' => :'date',
    :'date_precision' => :'date_precision',
    :'type' => :'type',
    :'title' => :'title',
    :'description' => :'description',
    :'primary_source_url' => :'primary_source_url'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/abliteration/models/event.rb', line 169

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



69
70
71
72
73
74
75
76
77
78
# File 'lib/abliteration/models/event.rb', line 69

def self.openapi_nullable
  Set.new([
    :'date',
    :'date_precision',
    :'type',
    :'title',
    :'description',
    :'primary_source_url'
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



56
57
58
59
60
61
62
63
64
65
66
# File 'lib/abliteration/models/event.rb', line 56

def self.openapi_types
  {
    :'id' => :'String',
    :'date' => :'String',
    :'date_precision' => :'String',
    :'type' => :'String',
    :'title' => :'String',
    :'description' => :'String',
    :'primary_source_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



142
143
144
145
146
147
148
149
150
151
152
# File 'lib/abliteration/models/event.rb', line 142

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      date == o.date &&
      date_precision == o.date_precision &&
      type == o.type &&
      title == o.title &&
      description == o.description &&
      primary_source_url == o.primary_source_url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


156
157
158
# File 'lib/abliteration/models/event.rb', line 156

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



162
163
164
# File 'lib/abliteration/models/event.rb', line 162

def hash
  [id, date, date_precision, type, title, description, primary_source_url].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



127
128
129
130
131
# File 'lib/abliteration/models/event.rb', line 127

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/abliteration/models/event.rb', line 191

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



135
136
137
138
# File 'lib/abliteration/models/event.rb', line 135

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end