Class: Abliteration::GetModelDownloadHistory200Response

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/abliteration/models/get_model_download_history200_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetModelDownloadHistory200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/abliteration/models/get_model_download_history200_response.rb', line 116

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Abliteration::GetModelDownloadHistory200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Abliteration::GetModelDownloadHistory200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'data')
    if (value = attributes[:'data']).is_a?(Array)
      self.data = value
    end
  else
    self.data = nil
  end

  if attributes.key?(:'cost')
    self.cost = attributes[:'cost']
  else
    self.cost = nil
  end

  if attributes.key?(:'credits_remaining')
    self.credits_remaining = attributes[:'credits_remaining']
  else
    self.credits_remaining = nil
  end

  if attributes.key?(:'rate_limit_limit')
    self.rate_limit_limit = attributes[:'rate_limit_limit']
  else
    self.rate_limit_limit = nil
  end

  if attributes.key?(:'rate_limit_remaining')
    self.rate_limit_remaining = attributes[:'rate_limit_remaining']
  else
    self.rate_limit_remaining = nil
  end

  if attributes.key?(:'rate_limit_reset')
    self.rate_limit_reset = attributes[:'rate_limit_reset']
  else
    self.rate_limit_reset = nil
  end

  if attributes.key?(:'metering')
    self.metering = attributes[:'metering']
  else
    self.metering = nil
  end

  if attributes.key?(:'request_id')
    self.request_id = attributes[:'request_id']
  else
    self.request_id = nil
  end
end

Instance Attribute Details

#cost ⇒ Object

Credits this call costs.



21
22
23
# File 'lib/abliteration/models/get_model_download_history200_response.rb', line 21

def cost
  @cost
end

#credits_remaining ⇒ Object

Wallet balance after the call. Unchanged while metering is preview.



24
25
26
# File 'lib/abliteration/models/get_model_download_history200_response.rb', line 24

def credits_remaining
  @credits_remaining
end

#data ⇒ Object

Returns the value of attribute data.



18
19
20
# File 'lib/abliteration/models/get_model_download_history200_response.rb', line 18

def data
  @data
end

#metering ⇒ Object

Whether cost was actually deducted.



36
37
38
# File 'lib/abliteration/models/get_model_download_history200_response.rb', line 36

def metering
  @metering
end

#rate_limit_limit ⇒ Object

Ceiling for the current window. Also returned as X-RateLimit-Limit.



27
28
29
# File 'lib/abliteration/models/get_model_download_history200_response.rb', line 27

def rate_limit_limit
  @rate_limit_limit
end

#rate_limit_remaining ⇒ Object

Calls left in the current window for this key. Also returned as X-RateLimit-Remaining.



30
31
32
# File 'lib/abliteration/models/get_model_download_history200_response.rb', line 30

def rate_limit_remaining
  @rate_limit_remaining
end

#rate_limit_reset ⇒ Object

Unix seconds at which the window resets to full ceiling. Also returned as X-RateLimit-Reset.



33
34
35
# File 'lib/abliteration/models/get_model_download_history200_response.rb', line 33

def rate_limit_reset
  @rate_limit_reset
end

#request_id ⇒ Object

Also returned in the x-request-id header.



39
40
41
# File 'lib/abliteration/models/get_model_download_history200_response.rb', line 39

def request_id
  @request_id
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



78
79
80
# File 'lib/abliteration/models/get_model_download_history200_response.rb', line 78

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



83
84
85
# File 'lib/abliteration/models/get_model_download_history200_response.rb', line 83

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/abliteration/models/get_model_download_history200_response.rb', line 64

def self.attribute_map
  {
    :'data' => :'data',
    :'cost' => :'cost',
    :'credits_remaining' => :'credits_remaining',
    :'rate_limit_limit' => :'rate_limit_limit',
    :'rate_limit_remaining' => :'rate_limit_remaining',
    :'rate_limit_reset' => :'rate_limit_reset',
    :'metering' => :'metering',
    :'request_id' => :'request_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/abliteration/models/get_model_download_history200_response.rb', line 348

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_of ⇒ Object

List of class defined in allOf (OpenAPI v3)



108
109
110
111
112
# File 'lib/abliteration/models/get_model_download_history200_response.rb', line 108

def self.openapi_all_of
  [
  :'Envelope'
  ]
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



102
103
104
105
# File 'lib/abliteration/models/get_model_download_history200_response.rb', line 102

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/abliteration/models/get_model_download_history200_response.rb', line 88

def self.openapi_types
  {
    :'data' => :'Array<DownloadPoint>',
    :'cost' => :'Integer',
    :'credits_remaining' => :'Integer',
    :'rate_limit_limit' => :'Integer',
    :'rate_limit_remaining' => :'Integer',
    :'rate_limit_reset' => :'Integer',
    :'metering' => :'String',
    :'request_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/abliteration/models/get_model_download_history200_response.rb', line 320

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      data == o.data &&
      cost == o.cost &&
      credits_remaining == o.credits_remaining &&
      rate_limit_limit == o.rate_limit_limit &&
      rate_limit_remaining == o.rate_limit_remaining &&
      rate_limit_reset == o.rate_limit_reset &&
      metering == o.metering &&
      request_id == o.request_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


335
336
337
# File 'lib/abliteration/models/get_model_download_history200_response.rb', line 335

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



341
342
343
# File 'lib/abliteration/models/get_model_download_history200_response.rb', line 341

def hash
  [data, cost, credits_remaining, rate_limit_limit, rate_limit_remaining, rate_limit_reset, metering, request_id].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/abliteration/models/get_model_download_history200_response.rb', line 183

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @data.nil?
    invalid_properties.push('invalid value for "data", data cannot be nil.')
  end

  if @cost.nil?
    invalid_properties.push('invalid value for "cost", cost cannot be nil.')
  end

  if @credits_remaining.nil?
    invalid_properties.push('invalid value for "credits_remaining", credits_remaining cannot be nil.')
  end

  if @rate_limit_limit.nil?
    invalid_properties.push('invalid value for "rate_limit_limit", rate_limit_limit cannot be nil.')
  end

  if @rate_limit_remaining.nil?
    invalid_properties.push('invalid value for "rate_limit_remaining", rate_limit_remaining cannot be nil.')
  end

  if @rate_limit_reset.nil?
    invalid_properties.push('invalid value for "rate_limit_reset", rate_limit_reset cannot be nil.')
  end

  if @metering.nil?
    invalid_properties.push('invalid value for "metering", metering cannot be nil.')
  end

  if @request_id.nil?
    invalid_properties.push('invalid value for "request_id", request_id cannot be nil.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



370
371
372
373
374
375
376
377
378
379
380
381
382
# File 'lib/abliteration/models/get_model_download_history200_response.rb', line 370

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/abliteration/models/get_model_download_history200_response.rb', line 223

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @data.nil?
  return false if @cost.nil?
  return false if @credits_remaining.nil?
  return false if @rate_limit_limit.nil?
  return false if @rate_limit_remaining.nil?
  return false if @rate_limit_reset.nil?
  return false if @metering.nil?
  metering_validator = EnumAttributeValidator.new('String', ["preview", "billed"])
  return false unless metering_validator.valid?(@metering)
  return false if @request_id.nil?
  true
end