Class: Abliteration::Index

Inherits:
ApiModelBase show all
Defined in:
lib/abliteration/models/index.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Index

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/abliteration/models/index.rb', line 115

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Abliteration::Index` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Abliteration::Index`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  end

  if attributes.key?(:'unit')
    self.unit = attributes[:'unit']
  end

  if attributes.key?(:'measured')
    self.measured = attributes[:'measured']
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  end

  if attributes.key?(:'history_available')
    self.history_available = attributes[:'history_available']
  end

  if attributes.key?(:'as_of')
    self.as_of = attributes[:'as_of']
  end

  if attributes.key?(:'note')
    self.note = attributes[:'note']
  end

  if attributes.key?(:'recent_history')
    if (value = attributes[:'recent_history']).is_a?(Array)
      self.recent_history = value
    end
  end
end

Instance Attribute Details

#as_of ⇒ Object

Returns the value of attribute as_of.



34
35
36
# File 'lib/abliteration/models/index.rb', line 34

def as_of
  @as_of
end

#history_available ⇒ Object

Returns the value of attribute history_available.



32
33
34
# File 'lib/abliteration/models/index.rb', line 32

def history_available
  @history_available
end

#id ⇒ Object

Returns the value of attribute id.



18
19
20
# File 'lib/abliteration/models/index.rb', line 18

def id
  @id
end

#measured ⇒ Object

False when the value is a placeholder constant rather than a measurement.



27
28
29
# File 'lib/abliteration/models/index.rb', line 27

def measured
  @measured
end

#name ⇒ Object

Returns the value of attribute name.



20
21
22
# File 'lib/abliteration/models/index.rb', line 20

def name
  @name
end

#note ⇒ Object

Returns the value of attribute note.



36
37
38
# File 'lib/abliteration/models/index.rb', line 36

def note
  @note
end

#recent_history ⇒ Object

Returns the value of attribute recent_history.



38
39
40
# File 'lib/abliteration/models/index.rb', line 38

def recent_history
  @recent_history
end

#source ⇒ Object

Where the number is produced.



30
31
32
# File 'lib/abliteration/models/index.rb', line 30

def source
  @source
end

#unit ⇒ Object

Returns the value of attribute unit.



24
25
26
# File 'lib/abliteration/models/index.rb', line 24

def unit
  @unit
end

#value ⇒ Object

Returns the value of attribute value.



22
23
24
# File 'lib/abliteration/models/index.rb', line 22

def value
  @value
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



79
80
81
# File 'lib/abliteration/models/index.rb', line 79

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/abliteration/models/index.rb', line 84

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/abliteration/models/index.rb', line 63

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'value' => :'value',
    :'unit' => :'unit',
    :'measured' => :'measured',
    :'source' => :'source',
    :'history_available' => :'history_available',
    :'as_of' => :'as_of',
    :'note' => :'note',
    :'recent_history' => :'recent_history'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/abliteration/models/index.rb', line 243

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



105
106
107
108
109
110
111
# File 'lib/abliteration/models/index.rb', line 105

def self.openapi_nullable
  Set.new([
    :'value',
    :'as_of',
    :'note',
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/abliteration/models/index.rb', line 89

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'value' => :'Float',
    :'unit' => :'String',
    :'measured' => :'Boolean',
    :'source' => :'String',
    :'history_available' => :'Boolean',
    :'as_of' => :'String',
    :'note' => :'String',
    :'recent_history' => :'Array<DaiPoint>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/abliteration/models/index.rb', line 213

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      value == o.value &&
      unit == o.unit &&
      measured == o.measured &&
      source == o.source &&
      history_available == o.history_available &&
      as_of == o.as_of &&
      note == o.note &&
      recent_history == o.recent_history
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


230
231
232
# File 'lib/abliteration/models/index.rb', line 230

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



236
237
238
# File 'lib/abliteration/models/index.rb', line 236

def hash
  [id, name, value, unit, measured, source, history_available, as_of, note, recent_history].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



174
175
176
177
178
# File 'lib/abliteration/models/index.rb', line 174

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/abliteration/models/index.rb', line 265

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



182
183
184
185
186
187
188
189
# File 'lib/abliteration/models/index.rb', line 182

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  id_validator = EnumAttributeValidator.new('String', ["dai", "freedom-velocity", "weaponization", "f2w-latency"])
  return false unless id_validator.valid?(@id)
  unit_validator = EnumAttributeValidator.new('String', ["percent", "days"])
  return false unless unit_validator.valid?(@unit)
  true
end