Class: Abliteration::IndicesApi
- Inherits:
-
Object
- Object
- Abliteration::IndicesApi
- Defined in:
- lib/abliteration/api/indices_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_index(id, opts = {}) ⇒ GetIndex200Response
One index with history Cost: 10 credits.
-
#get_index_with_http_info(id, opts = {}) ⇒ Array<(GetIndex200Response, Integer, Hash)>
One index with history Cost: 10 credits.
-
#initialize(api_client = ApiClient.default) ⇒ IndicesApi
constructor
A new instance of IndicesApi.
-
#list_indices(opts = {}) ⇒ ListIndices200Response
All four indices Cost: 20 credits.
-
#list_indices_with_http_info(opts = {}) ⇒ Array<(ListIndices200Response, Integer, Hash)>
All four indices Cost: 20 credits.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ IndicesApi
Returns a new instance of IndicesApi.
19 20 21 |
# File 'lib/abliteration/api/indices_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/abliteration/api/indices_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_index(id, opts = {}) ⇒ GetIndex200Response
One index with history Cost: 10 credits. Only dai has a history series; the others return an empty array with history_available false.
27 28 29 30 |
# File 'lib/abliteration/api/indices_api.rb', line 27 def get_index(id, opts = {}) data, _status_code, _headers = get_index_with_http_info(id, opts) data end |
#get_index_with_http_info(id, opts = {}) ⇒ Array<(GetIndex200Response, Integer, Hash)>
One index with history Cost: 10 credits. Only dai has a history series; the others return an empty array with history_available false.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/abliteration/api/indices_api.rb', line 37 def get_index_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IndicesApi.get_index ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling IndicesApi.get_index" end # verify enum value allowable_values = ["dai", "DAI", "freedom-velocity", "FV", "freedom_velocity", "weaponization", "WEAP", "f2w-latency", "F2W", "f2w_latency"] if @api_client.config.client_side_validation && !allowable_values.include?(id) fail ArgumentError, "invalid value for \"id\", must be one of #{allowable_values}" end # resource path local_var_path = '/api/v1/indices/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetIndex200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"IndicesApi.get_index", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IndicesApi#get_index\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_indices(opts = {}) ⇒ ListIndices200Response
All four indices Cost: 20 credits. Check the measured flag before treating a value as a finding.
94 95 96 97 |
# File 'lib/abliteration/api/indices_api.rb', line 94 def list_indices(opts = {}) data, _status_code, _headers = list_indices_with_http_info(opts) data end |
#list_indices_with_http_info(opts = {}) ⇒ Array<(ListIndices200Response, Integer, Hash)>
All four indices Cost: 20 credits. Check the measured flag before treating a value as a finding.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/abliteration/api/indices_api.rb', line 103 def list_indices_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IndicesApi.list_indices ...' end # resource path local_var_path = '/api/v1/indices' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListIndices200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"IndicesApi.list_indices", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IndicesApi#list_indices\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |