Class: Abliteration::Method

Inherits:
ApiModelBase show all
Defined in:
lib/abliteration/models/method.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Method

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/abliteration/models/method.rb', line 95

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Abliteration::Method` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Abliteration::Method`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'label')
    self.label = attributes[:'label']
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  end

  if attributes.key?(:'wiki_slug')
    self.wiki_slug = attributes[:'wiki_slug']
  end

  if attributes.key?(:'model_count')
    self.model_count = attributes[:'model_count']
  end

  if attributes.key?(:'total_downloads')
    self.total_downloads = attributes[:'total_downloads']
  end
end

Instance Attribute Details

#category ⇒ Object

Returns the value of attribute category.



22
23
24
# File 'lib/abliteration/models/method.rb', line 22

def category
  @category
end

#id ⇒ Object

Returns the value of attribute id.



18
19
20
# File 'lib/abliteration/models/method.rb', line 18

def id
  @id
end

#label ⇒ Object

Returns the value of attribute label.



20
21
22
# File 'lib/abliteration/models/method.rb', line 20

def label
  @label
end

#model_count ⇒ Object

Returns the value of attribute model_count.



26
27
28
# File 'lib/abliteration/models/method.rb', line 26

def model_count
  @model_count
end

#total_downloads ⇒ Object

Returns the value of attribute total_downloads.



28
29
30
# File 'lib/abliteration/models/method.rb', line 28

def total_downloads
  @total_downloads
end

#wiki_slug ⇒ Object

Returns the value of attribute wiki_slug.



24
25
26
# File 'lib/abliteration/models/method.rb', line 24

def wiki_slug
  @wiki_slug
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



65
66
67
# File 'lib/abliteration/models/method.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/abliteration/models/method.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
# File 'lib/abliteration/models/method.rb', line 53

def self.attribute_map
  {
    :'id' => :'id',
    :'label' => :'label',
    :'category' => :'category',
    :'wiki_slug' => :'wiki_slug',
    :'model_count' => :'model_count',
    :'total_downloads' => :'total_downloads'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/abliteration/models/method.rb', line 189

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



87
88
89
90
91
# File 'lib/abliteration/models/method.rb', line 87

def self.openapi_nullable
  Set.new([
    :'wiki_slug',
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
# File 'lib/abliteration/models/method.rb', line 75

def self.openapi_types
  {
    :'id' => :'String',
    :'label' => :'String',
    :'category' => :'String',
    :'wiki_slug' => :'String',
    :'model_count' => :'Integer',
    :'total_downloads' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



163
164
165
166
167
168
169
170
171
172
# File 'lib/abliteration/models/method.rb', line 163

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      label == o.label &&
      category == o.category &&
      wiki_slug == o.wiki_slug &&
      model_count == o.model_count &&
      total_downloads == o.total_downloads
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


176
177
178
# File 'lib/abliteration/models/method.rb', line 176

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



182
183
184
# File 'lib/abliteration/models/method.rb', line 182

def hash
  [id, label, category, wiki_slug, model_count, total_downloads].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



136
137
138
139
140
# File 'lib/abliteration/models/method.rb', line 136

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/abliteration/models/method.rb', line 211

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



144
145
146
147
148
149
# File 'lib/abliteration/models/method.rb', line 144

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  category_validator = EnumAttributeValidator.new('String', ["original", "repackage", "merged", "unclassified"])
  return false unless category_validator.valid?(@category)
  true
end