Class: Abliteration::MethodDetail
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Abliteration::MethodDetail
- Defined in:
- lib/abliteration/models/method_detail.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#category ⇒ Object
Returns the value of attribute category.
-
#id ⇒ Object
Returns the value of attribute id.
-
#label ⇒ Object
Returns the value of attribute label.
-
#model_count ⇒ Object
Returns the value of attribute model_count.
-
#sample_models ⇒ Object
Returns the value of attribute sample_models.
-
#top_authors ⇒ Object
Returns the value of attribute top_authors.
-
#total_downloads ⇒ Object
Returns the value of attribute total_downloads.
-
#wiki_slug ⇒ Object
Returns the value of attribute wiki_slug.
-
#wiki_url ⇒ Object
Returns the value of attribute wiki_url.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MethodDetail
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MethodDetail
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/abliteration/models/method_detail.rb', line 114 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Abliteration::MethodDetail` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Abliteration::MethodDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'label') self.label = attributes[:'label'] end if attributes.key?(:'category') self.category = attributes[:'category'] end if attributes.key?(:'wiki_slug') self.wiki_slug = attributes[:'wiki_slug'] end if attributes.key?(:'model_count') self.model_count = attributes[:'model_count'] end if attributes.key?(:'total_downloads') self.total_downloads = attributes[:'total_downloads'] end if attributes.key?(:'wiki_url') self.wiki_url = attributes[:'wiki_url'] end if attributes.key?(:'top_authors') if (value = attributes[:'top_authors']).is_a?(Array) self. = value end end if attributes.key?(:'sample_models') if (value = attributes[:'sample_models']).is_a?(Array) self.sample_models = value end end end |
Instance Attribute Details
#category ⇒ Object
Returns the value of attribute category.
22 23 24 |
# File 'lib/abliteration/models/method_detail.rb', line 22 def category @category end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/abliteration/models/method_detail.rb', line 18 def id @id end |
#label ⇒ Object
Returns the value of attribute label.
20 21 22 |
# File 'lib/abliteration/models/method_detail.rb', line 20 def label @label end |
#model_count ⇒ Object
Returns the value of attribute model_count.
26 27 28 |
# File 'lib/abliteration/models/method_detail.rb', line 26 def model_count @model_count end |
#sample_models ⇒ Object
Returns the value of attribute sample_models.
34 35 36 |
# File 'lib/abliteration/models/method_detail.rb', line 34 def sample_models @sample_models end |
#top_authors ⇒ Object
Returns the value of attribute top_authors.
32 33 34 |
# File 'lib/abliteration/models/method_detail.rb', line 32 def end |
#total_downloads ⇒ Object
Returns the value of attribute total_downloads.
28 29 30 |
# File 'lib/abliteration/models/method_detail.rb', line 28 def total_downloads @total_downloads end |
#wiki_slug ⇒ Object
Returns the value of attribute wiki_slug.
24 25 26 |
# File 'lib/abliteration/models/method_detail.rb', line 24 def wiki_slug @wiki_slug end |
#wiki_url ⇒ Object
Returns the value of attribute wiki_url.
30 31 32 |
# File 'lib/abliteration/models/method_detail.rb', line 30 def wiki_url @wiki_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
74 75 76 |
# File 'lib/abliteration/models/method_detail.rb', line 74 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/abliteration/models/method_detail.rb', line 79 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/abliteration/models/method_detail.rb', line 59 def self.attribute_map { :'id' => :'id', :'label' => :'label', :'category' => :'category', :'wiki_slug' => :'wiki_slug', :'model_count' => :'model_count', :'total_downloads' => :'total_downloads', :'wiki_url' => :'wiki_url', :'top_authors' => :'top_authors', :'sample_models' => :'sample_models' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/abliteration/models/method_detail.rb', line 227 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
106 107 108 109 110 |
# File 'lib/abliteration/models/method_detail.rb', line 106 def self.openapi_all_of [ :'Method' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 103 |
# File 'lib/abliteration/models/method_detail.rb', line 99 def self.openapi_nullable Set.new([ :'wiki_url', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/abliteration/models/method_detail.rb', line 84 def self.openapi_types { :'id' => :'String', :'label' => :'String', :'category' => :'String', :'wiki_slug' => :'String', :'model_count' => :'Integer', :'total_downloads' => :'Integer', :'wiki_url' => :'String', :'top_authors' => :'Array<MethodDetailAllOfTopAuthors>', :'sample_models' => :'Array<ModelSummary>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/abliteration/models/method_detail.rb', line 198 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && label == o.label && category == o.category && wiki_slug == o.wiki_slug && model_count == o.model_count && total_downloads == o.total_downloads && wiki_url == o.wiki_url && == o. && sample_models == o.sample_models end |
#eql?(o) ⇒ Boolean
214 215 216 |
# File 'lib/abliteration/models/method_detail.rb', line 214 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
220 221 222 |
# File 'lib/abliteration/models/method_detail.rb', line 220 def hash [id, label, category, wiki_slug, model_count, total_downloads, wiki_url, , sample_models].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
171 172 173 174 175 |
# File 'lib/abliteration/models/method_detail.rb', line 171 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/abliteration/models/method_detail.rb', line 249 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
179 180 181 182 183 184 |
# File 'lib/abliteration/models/method_detail.rb', line 179 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' category_validator = EnumAttributeValidator.new('String', ["original", "repackage", "merged", "unclassified"]) return false unless category_validator.valid?(@category) true end |