Class: Abliteration::MethodsApi
- Inherits:
-
Object
- Object
- Abliteration::MethodsApi
- Defined in:
- lib/abliteration/api/methods_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_method(id, opts = {}) ⇒ GetMethod200Response
Get one method Cost: 1 credit.
-
#get_method_with_http_info(id, opts = {}) ⇒ Array<(GetMethod200Response, Integer, Hash)>
Get one method Cost: 1 credit.
-
#initialize(api_client = ApiClient.default) ⇒ MethodsApi
constructor
A new instance of MethodsApi.
-
#list_methods(opts = {}) ⇒ ListMethods200Response
List the method taxonomy Cost: 5-15 credits.
-
#list_methods_with_http_info(opts = {}) ⇒ Array<(ListMethods200Response, Integer, Hash)>
List the method taxonomy Cost: 5-15 credits.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ MethodsApi
Returns a new instance of MethodsApi.
19 20 21 |
# File 'lib/abliteration/api/methods_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/abliteration/api/methods_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_method(id, opts = {}) ⇒ GetMethod200Response
Get one method Cost: 1 credit.
27 28 29 30 |
# File 'lib/abliteration/api/methods_api.rb', line 27 def get_method(id, opts = {}) data, _status_code, _headers = get_method_with_http_info(id, opts) data end |
#get_method_with_http_info(id, opts = {}) ⇒ Array<(GetMethod200Response, Integer, Hash)>
Get one method Cost: 1 credit.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/abliteration/api/methods_api.rb', line 37 def get_method_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MethodsApi.get_method ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling MethodsApi.get_method" end # verify enum value allowable_values = ["M1", "M2", "M3", "M4", "M5", "M5-frankenstein", "M6", "M7", "M8", "M-uncensored", "unknown"] if @api_client.config.client_side_validation && !allowable_values.include?(id) fail ArgumentError, "invalid value for \"id\", must be one of #{allowable_values}" end # resource path local_var_path = '/api/v1/methods/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetMethod200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"MethodsApi.get_method", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MethodsApi#get_method\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_methods(opts = {}) ⇒ ListMethods200Response
List the method taxonomy Cost: 5-15 credits. Every code is returned, including ones with no models.
94 95 96 97 |
# File 'lib/abliteration/api/methods_api.rb', line 94 def list_methods(opts = {}) data, _status_code, _headers = list_methods_with_http_info(opts) data end |
#list_methods_with_http_info(opts = {}) ⇒ Array<(ListMethods200Response, Integer, Hash)>
List the method taxonomy Cost: 5-15 credits. Every code is returned, including ones with no models.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/abliteration/api/methods_api.rb', line 103 def list_methods_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MethodsApi.list_methods ...' end # resource path local_var_path = '/api/v1/methods' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListMethods200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"MethodsApi.list_methods", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MethodsApi#list_methods\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |