Class: Abliteration::ModelSummary

Inherits:
ApiModelBase show all
Defined in:
lib/abliteration/models/model_summary.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ModelSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/abliteration/models/model_summary.rb', line 122

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Abliteration::ModelSummary` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Abliteration::ModelSummary`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'author')
    self.author = attributes[:'author']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'method')
    self.method = attributes[:'method']
  end

  if attributes.key?(:'confidence')
    self.confidence = attributes[:'confidence']
  end

  if attributes.key?(:'family')
    self.family = attributes[:'family']
  end

  if attributes.key?(:'params_b')
    self.params_b = attributes[:'params_b']
  end

  if attributes.key?(:'license')
    self.license = attributes[:'license']
  end

  if attributes.key?(:'downloads')
    self.downloads = attributes[:'downloads']
  end

  if attributes.key?(:'likes')
    self.likes = attributes[:'likes']
  end

  if attributes.key?(:'is_gguf')
    self.is_gguf = attributes[:'is_gguf']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'first_seen_at')
    self.first_seen_at = attributes[:'first_seen_at']
  end

  if attributes.key?(:'is_delisted')
    self.is_delisted = attributes[:'is_delisted']
  end

  if attributes.key?(:'last_seen_at')
    self.last_seen_at = attributes[:'last_seen_at']
  end
end

Instance Attribute Details

#author ⇒ Object

Returns the value of attribute author.



20
21
22
# File 'lib/abliteration/models/model_summary.rb', line 20

def author
  @author
end

#confidence ⇒ Object

Returns the value of attribute confidence.



26
27
28
# File 'lib/abliteration/models/model_summary.rb', line 26

def confidence
  @confidence
end

#created_at ⇒ Object

Returns the value of attribute created_at.



40
41
42
# File 'lib/abliteration/models/model_summary.rb', line 40

def created_at
  @created_at
end

#downloads ⇒ Object

Returns the value of attribute downloads.



34
35
36
# File 'lib/abliteration/models/model_summary.rb', line 34

def downloads
  @downloads
end

#family ⇒ Object

Returns the value of attribute family.



28
29
30
# File 'lib/abliteration/models/model_summary.rb', line 28

def family
  @family
end

#first_seen_at ⇒ Object

Returns the value of attribute first_seen_at.



42
43
44
# File 'lib/abliteration/models/model_summary.rb', line 42

def first_seen_at
  @first_seen_at
end

#id ⇒ Object

Returns the value of attribute id.



18
19
20
# File 'lib/abliteration/models/model_summary.rb', line 18

def id
  @id
end

#is_delisted ⇒ Object

0/1 flag, present in every response row. 1 means the model is no longer on the Hub.



45
46
47
# File 'lib/abliteration/models/model_summary.rb', line 45

def is_delisted
  @is_delisted
end

#is_gguf ⇒ Object

Returns the value of attribute is_gguf.



38
39
40
# File 'lib/abliteration/models/model_summary.rb', line 38

def is_gguf
  @is_gguf
end

#last_seen_at ⇒ Object

ISO-8601 timestamp of the last successful Hub observation. Non-null on delisted rows.



48
49
50
# File 'lib/abliteration/models/model_summary.rb', line 48

def last_seen_at
  @last_seen_at
end

#license ⇒ Object

Returns the value of attribute license.



32
33
34
# File 'lib/abliteration/models/model_summary.rb', line 32

def license
  @license
end

#likes ⇒ Object

Returns the value of attribute likes.



36
37
38
# File 'lib/abliteration/models/model_summary.rb', line 36

def likes
  @likes
end

#method ⇒ Object

Returns the value of attribute method.



24
25
26
# File 'lib/abliteration/models/model_summary.rb', line 24

def method
  @method
end

#name ⇒ Object

Returns the value of attribute name.



22
23
24
# File 'lib/abliteration/models/model_summary.rb', line 22

def name
  @name
end

#params_b ⇒ Object

Returns the value of attribute params_b.



30
31
32
# File 'lib/abliteration/models/model_summary.rb', line 30

def params_b
  @params_b
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



72
73
74
# File 'lib/abliteration/models/model_summary.rb', line 72

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/abliteration/models/model_summary.rb', line 77

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/abliteration/models/model_summary.rb', line 51

def self.attribute_map
  {
    :'id' => :'id',
    :'author' => :'author',
    :'name' => :'name',
    :'method' => :'method',
    :'confidence' => :'confidence',
    :'family' => :'family',
    :'params_b' => :'params_b',
    :'license' => :'license',
    :'downloads' => :'downloads',
    :'likes' => :'likes',
    :'is_gguf' => :'is_gguf',
    :'created_at' => :'created_at',
    :'first_seen_at' => :'first_seen_at',
    :'is_delisted' => :'is_delisted',
    :'last_seen_at' => :'last_seen_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/abliteration/models/model_summary.rb', line 249

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/abliteration/models/model_summary.rb', line 103

def self.openapi_nullable
  Set.new([
    :'method',
    :'confidence',
    :'family',
    :'params_b',
    :'license',
    :'downloads',
    :'likes',
    :'is_gguf',
    :'created_at',
    :'first_seen_at',
    :'is_delisted',
    :'last_seen_at'
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/abliteration/models/model_summary.rb', line 82

def self.openapi_types
  {
    :'id' => :'String',
    :'author' => :'String',
    :'name' => :'String',
    :'method' => :'String',
    :'confidence' => :'String',
    :'family' => :'String',
    :'params_b' => :'Float',
    :'license' => :'String',
    :'downloads' => :'Integer',
    :'likes' => :'Integer',
    :'is_gguf' => :'Integer',
    :'created_at' => :'String',
    :'first_seen_at' => :'String',
    :'is_delisted' => :'Integer',
    :'last_seen_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/abliteration/models/model_summary.rb', line 214

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      author == o.author &&
      name == o.name &&
      method == o.method &&
      confidence == o.confidence &&
      family == o.family &&
      params_b == o.params_b &&
      license == o.license &&
      downloads == o.downloads &&
      likes == o.likes &&
      is_gguf == o.is_gguf &&
      created_at == o.created_at &&
      first_seen_at == o.first_seen_at &&
      is_delisted == o.is_delisted &&
      last_seen_at == o.last_seen_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


236
237
238
# File 'lib/abliteration/models/model_summary.rb', line 236

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



242
243
244
# File 'lib/abliteration/models/model_summary.rb', line 242

def hash
  [id, author, name, method, confidence, family, params_b, license, downloads, likes, is_gguf, created_at, first_seen_at, is_delisted, last_seen_at].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



199
200
201
202
203
# File 'lib/abliteration/models/model_summary.rb', line 199

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/abliteration/models/model_summary.rb', line 271

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



207
208
209
210
# File 'lib/abliteration/models/model_summary.rb', line 207

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end