Class: Abliteration::TimelineApi

Inherits:
Object
  • Object
show all
Defined in:
lib/abliteration/api/timeline_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ TimelineApi

Returns a new instance of TimelineApi.



19
20
21
# File 'lib/abliteration/api/timeline_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_client ⇒ Object

Returns the value of attribute api_client.



17
18
19
# File 'lib/abliteration/api/timeline_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#list_timeline(opts = {}) ⇒ ListTimeline200Response

Curated field events Cost: 50 credits, flat.

Parameters:

  • opts (Hash) (defaults to: {}) —

    the optional parameters

Options Hash (opts):

  • :from (String) —

    Inclusive lower bound on the event date, ISO-8601.

  • :to (String) —

    Inclusive upper bound on the event date, ISO-8601.

  • :event_type (String) —

    Event type, case-insensitive.

  • :limit (Integer) — default: default to 100

Returns:



30
31
32
33
# File 'lib/abliteration/api/timeline_api.rb', line 30

def list_timeline(opts = {})
  data, _status_code, _headers = list_timeline_with_http_info(opts)
  data
end

#list_timeline_with_http_info(opts = {}) ⇒ Array<(ListTimeline200Response, Integer, Hash)>

Curated field events Cost: 50 credits, flat.

Parameters:

  • opts (Hash) (defaults to: {}) —

    the optional parameters

Options Hash (opts):

  • :from (String) —

    Inclusive lower bound on the event date, ISO-8601.

  • :to (String) —

    Inclusive upper bound on the event date, ISO-8601.

  • :event_type (String) —

    Event type, case-insensitive.

  • :limit (Integer) — default: default to 100

Returns:

  • (Array<(ListTimeline200Response, Integer, Hash)>) —

    ListTimeline200Response data, response status code and response headers



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/abliteration/api/timeline_api.rb', line 43

def list_timeline_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TimelineApi.list_timeline ...'
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 1000
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling TimelineApi.list_timeline, must be smaller than or equal to 1000.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling TimelineApi.list_timeline, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/api/v1/timeline'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'from'] = opts[:'from'] if !opts[:'from'].nil?
  query_params[:'to'] = opts[:'to'] if !opts[:'to'].nil?
  query_params[:'event_type'] = opts[:'event_type'] if !opts[:'event_type'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListTimeline200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"TimelineApi.list_timeline",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TimelineApi#list_timeline\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end