Class: Abliteration::AuthorDetail
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Abliteration::AuthorDetail
- Defined in:
- lib/abliteration/models/author_detail.rb
Instance Attribute Summary collapse
-
#author ⇒ Object
Returns the value of attribute author.
-
#first_seen_at ⇒ Object
Returns the value of attribute first_seen_at.
-
#id ⇒ Object
Same value as
author; added for consistency with the other single-entity payloads. -
#models ⇒ Object
Returns the value of attribute models.
-
#total_downloads ⇒ Object
Returns the value of attribute total_downloads.
-
#total_likes ⇒ Object
Returns the value of attribute total_likes.
-
#total_models ⇒ Object
Returns the value of attribute total_models.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AuthorDetail
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AuthorDetail
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/abliteration/models/author_detail.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Abliteration::AuthorDetail` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Abliteration::AuthorDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'author') self. = attributes[:'author'] end if attributes.key?(:'total_models') self.total_models = attributes[:'total_models'] end if attributes.key?(:'total_downloads') self.total_downloads = attributes[:'total_downloads'] end if attributes.key?(:'total_likes') self.total_likes = attributes[:'total_likes'] end if attributes.key?(:'first_seen_at') self.first_seen_at = attributes[:'first_seen_at'] end if attributes.key?(:'models') if (value = attributes[:'models']).is_a?(Array) self.models = value end end end |
Instance Attribute Details
#author ⇒ Object
Returns the value of attribute author.
21 22 23 |
# File 'lib/abliteration/models/author_detail.rb', line 21 def end |
#first_seen_at ⇒ Object
Returns the value of attribute first_seen_at.
29 30 31 |
# File 'lib/abliteration/models/author_detail.rb', line 29 def first_seen_at @first_seen_at end |
#id ⇒ Object
Same value as author; added for consistency with the other single-entity payloads.
19 20 21 |
# File 'lib/abliteration/models/author_detail.rb', line 19 def id @id end |
#models ⇒ Object
Returns the value of attribute models.
31 32 33 |
# File 'lib/abliteration/models/author_detail.rb', line 31 def models @models end |
#total_downloads ⇒ Object
Returns the value of attribute total_downloads.
25 26 27 |
# File 'lib/abliteration/models/author_detail.rb', line 25 def total_downloads @total_downloads end |
#total_likes ⇒ Object
Returns the value of attribute total_likes.
27 28 29 |
# File 'lib/abliteration/models/author_detail.rb', line 27 def total_likes @total_likes end |
#total_models ⇒ Object
Returns the value of attribute total_models.
23 24 25 |
# File 'lib/abliteration/models/author_detail.rb', line 23 def total_models @total_models end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
47 48 49 |
# File 'lib/abliteration/models/author_detail.rb', line 47 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
52 53 54 |
# File 'lib/abliteration/models/author_detail.rb', line 52 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/abliteration/models/author_detail.rb', line 34 def self.attribute_map { :'id' => :'id', :'author' => :'author', :'total_models' => :'total_models', :'total_downloads' => :'total_downloads', :'total_likes' => :'total_likes', :'first_seen_at' => :'first_seen_at', :'models' => :'models' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/abliteration/models/author_detail.rb', line 173 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
76 77 78 79 80 |
# File 'lib/abliteration/models/author_detail.rb', line 76 def self.openapi_all_of [ :'Author' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
70 71 72 73 |
# File 'lib/abliteration/models/author_detail.rb', line 70 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/abliteration/models/author_detail.rb', line 57 def self.openapi_types { :'id' => :'String', :'author' => :'String', :'total_models' => :'Integer', :'total_downloads' => :'Integer', :'total_likes' => :'Integer', :'first_seen_at' => :'String', :'models' => :'Array<ModelSummary>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/abliteration/models/author_detail.rb', line 146 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && == o. && total_models == o.total_models && total_downloads == o.total_downloads && total_likes == o.total_likes && first_seen_at == o.first_seen_at && models == o.models end |
#eql?(o) ⇒ Boolean
160 161 162 |
# File 'lib/abliteration/models/author_detail.rb', line 160 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
166 167 168 |
# File 'lib/abliteration/models/author_detail.rb', line 166 def hash [id, , total_models, total_downloads, total_likes, first_seen_at, models].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
131 132 133 134 135 |
# File 'lib/abliteration/models/author_detail.rb', line 131 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/abliteration/models/author_detail.rb', line 195 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
139 140 141 142 |
# File 'lib/abliteration/models/author_detail.rb', line 139 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |